pub struct UID {
pub id: ID,
}Expand description
Globally unique IDs that define an object’s ID in storage. Any Sui Object, that is a struct
with the key ability, must have id: UID as its first field.
These are globally unique in the sense that no two values of type UID are ever equal, in
other words for any two values id1: UID and id2: UID, id1 != id2.
This is a privileged type that can only be derived from a TxContext.
UID doesn’t have the drop ability, so deleting a UID requires a call to delete.
Fields
id: IDImplementations